@@ -70,12 +70,11 @@ void MusicBrainzTestSeveralDiscs::testLookup()
 
   CDInfoList response = c.lookupResponse();
 
-  qDebug() << "Client::lookup returned : " << response.count() << " entries"
-    << endl;
+  qDebug() << "Client::lookup returned : " << response.count() << " entries";
 
   QVERIFY(response.count() > 0);
 
-  // See http://musicbrainz.org/release/4e0655b5-22fc-496e-9c14-2ee1a6027b45 for changes (disc 2)
+  // See https://musicbrainz.org/release/4e0655b5-22fc-496e-9c14-2ee1a6027b45 for changes (disc 2)
   CDInfo i(response.first());
   QCOMPARE(i.numberOfTracks(),20);
 
@@ -102,7 +101,7 @@ void MusicBrainzTestSeveralDiscs::testLookup()
   QCOMPARE(i.track(15).get(Title).toString(),QString::fromUtf8("All You Fascists Bound to Lose (Blokes version)"));
   QCOMPARE(i.track(16).get(Title).toString(),QString::fromUtf8("NPWA"));
   QCOMPARE(i.track(17).get(Title).toString(),QString::fromUtf8("St. Monday"));
-  QCOMPARE(i.track(18).get(Title).toString(),QString::fromUtf8("Some Days I See the Point"));
+  QCOMPARE(i.track(18).get(Title).toString(),QString::fromUtf8("Somedays I See the Point"));
   QCOMPARE(i.track(19).get(Title).toString(),QString::fromUtf8("Take Down the Union Jack (Band version)"));
   for (int j=0; j < 12; j++)
     QCOMPARE(i.track(j).get(Artist).toString(),QString::fromUtf8("Billy Bragg"));
